<div class="especial-dos" style="margin-bottom: 10px;">
    <table>
        <tr>
            <td class="celda-i" style="width: 50%;">
                <label style="font-weight: bold; color: #002857;">{{ label1 }}</label>
                <input type="text" value="{{ valor1 }}" style="width: 100%;">
            </td>
        </tr>
        <tr>
            <td class="celda-c" style="width: 50%;">
                <label style="font-weight: bold; color: #002857;">{{ label2 }}</label>
                <input type="text" value="{{ valor2 }}" style="width: 100%;">
            </td>
        </tr>
    </table>
</div>